Class: Aws::WorkDocs::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::WorkDocs::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-workdocs/client.rb
Overview
An API client for WorkDocs. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::WorkDocs::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#abort_document_version_upload(params = {}) ⇒ Struct
Aborts the upload of the specified document version that was previously initiated by InitiateDocumentVersionUpload.
-
#activate_user(params = {}) ⇒ Types::ActivateUserResponse
Activates the specified user.
-
#add_resource_permissions(params = {}) ⇒ Types::AddResourcePermissionsResponse
Creates a set of permissions for the specified folder or document.
-
#create_comment(params = {}) ⇒ Types::CreateCommentResponse
Adds a new comment to the specified document version.
-
#create_custom_metadata(params = {}) ⇒ Struct
Adds one or more custom properties to the specified resource (a folder, document, or version).
-
#create_folder(params = {}) ⇒ Types::CreateFolderResponse
Creates a folder with the specified name and parent folder.
-
#create_labels(params = {}) ⇒ Struct
Adds the specified list of labels to the given resource (a document or folder).
-
#create_notification_subscription(params = {}) ⇒ Types::CreateNotificationSubscriptionResponse
Configure Amazon WorkDocs to use Amazon SNS notifications.
-
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user in a Simple AD or Microsoft AD directory.
-
#deactivate_user(params = {}) ⇒ Struct
Deactivates the specified user, which revokes the user’s access to Amazon WorkDocs.
-
#delete_comment(params = {}) ⇒ Struct
Deletes the specified comment from the document version.
-
#delete_custom_metadata(params = {}) ⇒ Struct
Deletes custom metadata from the specified resource.
-
#delete_document(params = {}) ⇒ Struct
Permanently deletes the specified document and its associated metadata.
-
#delete_document_version(params = {}) ⇒ Struct
Deletes a specific version of a document.
-
#delete_folder(params = {}) ⇒ Struct
Permanently deletes the specified folder and its contents.
-
#delete_folder_contents(params = {}) ⇒ Struct
Deletes the contents of the specified folder.
-
#delete_labels(params = {}) ⇒ Struct
Deletes the specified list of labels from a resource.
-
#delete_notification_subscription(params = {}) ⇒ Struct
Deletes the specified subscription from the specified organization.
-
#delete_user(params = {}) ⇒ Struct
Deletes the specified user from a Simple AD or Microsoft AD directory.
-
#describe_activities(params = {}) ⇒ Types::DescribeActivitiesResponse
Describes the user activities in a specified time period.
-
#describe_comments(params = {}) ⇒ Types::DescribeCommentsResponse
List all the comments for the specified document version.
-
#describe_document_versions(params = {}) ⇒ Types::DescribeDocumentVersionsResponse
Retrieves the document versions for the specified document.
-
#describe_folder_contents(params = {}) ⇒ Types::DescribeFolderContentsResponse
Describes the contents of the specified folder, including its documents and subfolders.
-
#describe_groups(params = {}) ⇒ Types::DescribeGroupsResponse
Describes the groups specified by the query.
-
#describe_notification_subscriptions(params = {}) ⇒ Types::DescribeNotificationSubscriptionsResponse
Lists the specified notification subscriptions.
-
#describe_resource_permissions(params = {}) ⇒ Types::DescribeResourcePermissionsResponse
Describes the permissions of a specified resource.
-
#describe_root_folders(params = {}) ⇒ Types::DescribeRootFoldersResponse
Describes the current user’s special folders; the ‘RootFolder` and the `RecycleBin`.
-
#describe_users(params = {}) ⇒ Types::DescribeUsersResponse
Describes the specified users.
-
#get_current_user(params = {}) ⇒ Types::GetCurrentUserResponse
Retrieves details of the current user for whom the authentication token was generated.
-
#get_document(params = {}) ⇒ Types::GetDocumentResponse
Retrieves details of a document.
-
#get_document_path(params = {}) ⇒ Types::GetDocumentPathResponse
Retrieves the path information (the hierarchy from the root folder) for the requested document.
-
#get_document_version(params = {}) ⇒ Types::GetDocumentVersionResponse
Retrieves version metadata for the specified document.
-
#get_folder(params = {}) ⇒ Types::GetFolderResponse
Retrieves the metadata of the specified folder.
-
#get_folder_path(params = {}) ⇒ Types::GetFolderPathResponse
Retrieves the path information (the hierarchy from the root folder) for the specified folder.
-
#get_resources(params = {}) ⇒ Types::GetResourcesResponse
Retrieves a collection of resources, including folders and documents.
-
#initiate_document_version_upload(params = {}) ⇒ Types::InitiateDocumentVersionUploadResponse
Creates a new document object and version object.
-
#remove_all_resource_permissions(params = {}) ⇒ Struct
Removes all the permissions from the specified resource.
-
#remove_resource_permission(params = {}) ⇒ Struct
Removes the permission for the specified principal from the specified resource.
-
#restore_document_versions(params = {}) ⇒ Struct
Recovers a deleted version of an Amazon WorkDocs document.
-
#search_resources(params = {}) ⇒ Types::SearchResourcesResponse
Searches metadata and the content of folders, documents, document versions, and comments.
-
#update_document(params = {}) ⇒ Struct
Updates the specified attributes of a document.
-
#update_document_version(params = {}) ⇒ Struct
Changes the status of the document version to ACTIVE.
-
#update_folder(params = {}) ⇒ Struct
Updates the specified attributes of the specified folder.
-
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Updates the specified attributes of the specified user, and grants or revokes administrative privileges to the Amazon WorkDocs site.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-workdocs/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3020 3021 3022 |
# File 'lib/aws-sdk-workdocs/client.rb', line 3020 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3023 3024 3025 |
# File 'lib/aws-sdk-workdocs/client.rb', line 3023 def errors_module Errors end |
Instance Method Details
#abort_document_version_upload(params = {}) ⇒ Struct
Aborts the upload of the specified document version that was previously initiated by InitiateDocumentVersionUpload. The client should make this call only when it no longer intends to upload the document version, or fails to do so.
506 507 508 509 |
# File 'lib/aws-sdk-workdocs/client.rb', line 506 def abort_document_version_upload(params = {}, = {}) req = build_request(:abort_document_version_upload, params) req.send_request() end |
#activate_user(params = {}) ⇒ Types::ActivateUserResponse
Activates the specified user. Only active users can access Amazon WorkDocs.
556 557 558 559 |
# File 'lib/aws-sdk-workdocs/client.rb', line 556 def activate_user(params = {}, = {}) req = build_request(:activate_user, params) req.send_request() end |
#add_resource_permissions(params = {}) ⇒ Types::AddResourcePermissionsResponse
Creates a set of permissions for the specified folder or document. The resource permissions are overwritten if the principals already have different permissions.
614 615 616 617 |
# File 'lib/aws-sdk-workdocs/client.rb', line 614 def (params = {}, = {}) req = build_request(:add_resource_permissions, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2993 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::WorkDocs') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-workdocs' context[:gem_version] = '1.90.0' Seahorse::Client::Request.new(handlers, context) end |
#create_comment(params = {}) ⇒ Types::CreateCommentResponse
Adds a new comment to the specified document version.
699 700 701 702 |
# File 'lib/aws-sdk-workdocs/client.rb', line 699 def create_comment(params = {}, = {}) req = build_request(:create_comment, params) req.send_request() end |
#create_custom_metadata(params = {}) ⇒ Struct
Adds one or more custom properties to the specified resource (a folder, document, or version).
738 739 740 741 |
# File 'lib/aws-sdk-workdocs/client.rb', line 738 def (params = {}, = {}) req = build_request(:create_custom_metadata, params) req.send_request() end |
#create_folder(params = {}) ⇒ Types::CreateFolderResponse
Creates a folder with the specified name and parent folder.
786 787 788 789 |
# File 'lib/aws-sdk-workdocs/client.rb', line 786 def create_folder(params = {}, = {}) req = build_request(:create_folder, params) req.send_request() end |
#create_labels(params = {}) ⇒ Struct
Adds the specified list of labels to the given resource (a document or folder)
818 819 820 821 |
# File 'lib/aws-sdk-workdocs/client.rb', line 818 def create_labels(params = {}, = {}) req = build_request(:create_labels, params) req.send_request() end |
#create_notification_subscription(params = {}) ⇒ Types::CreateNotificationSubscriptionResponse
Configure Amazon WorkDocs to use Amazon SNS notifications. The endpoint receives a confirmation message, and must confirm the subscription.
For more information, see [Setting up notifications for an IAM user or role] in the *Amazon WorkDocs Developer Guide*.
[1]: docs.aws.amazon.com/workdocs/latest/developerguide/manage-notifications.html
871 872 873 874 |
# File 'lib/aws-sdk-workdocs/client.rb', line 871 def create_notification_subscription(params = {}, = {}) req = build_request(:create_notification_subscription, params) req.send_request() end |
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user in a Simple AD or Microsoft AD directory. The status of a newly created user is “ACTIVE”. New users can access Amazon WorkDocs.
953 954 955 956 |
# File 'lib/aws-sdk-workdocs/client.rb', line 953 def create_user(params = {}, = {}) req = build_request(:create_user, params) req.send_request() end |
#deactivate_user(params = {}) ⇒ Struct
Deactivates the specified user, which revokes the user’s access to Amazon WorkDocs.
981 982 983 984 |
# File 'lib/aws-sdk-workdocs/client.rb', line 981 def deactivate_user(params = {}, = {}) req = build_request(:deactivate_user, params) req.send_request() end |
#delete_comment(params = {}) ⇒ Struct
Deletes the specified comment from the document version.
1016 1017 1018 1019 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1016 def delete_comment(params = {}, = {}) req = build_request(:delete_comment, params) req.send_request() end |
#delete_custom_metadata(params = {}) ⇒ Struct
Deletes custom metadata from the specified resource.
1057 1058 1059 1060 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1057 def (params = {}, = {}) req = build_request(:delete_custom_metadata, params) req.send_request() end |
#delete_document(params = {}) ⇒ Struct
Permanently deletes the specified document and its associated metadata.
1085 1086 1087 1088 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1085 def delete_document(params = {}, = {}) req = build_request(:delete_document, params) req.send_request() end |
#delete_document_version(params = {}) ⇒ Struct
Deletes a specific version of a document.
1120 1121 1122 1123 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1120 def delete_document_version(params = {}, = {}) req = build_request(:delete_document_version, params) req.send_request() end |
#delete_folder(params = {}) ⇒ Struct
Permanently deletes the specified folder and its contents.
1147 1148 1149 1150 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1147 def delete_folder(params = {}, = {}) req = build_request(:delete_folder, params) req.send_request() end |
#delete_folder_contents(params = {}) ⇒ Struct
Deletes the contents of the specified folder.
1174 1175 1176 1177 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1174 def delete_folder_contents(params = {}, = {}) req = build_request(:delete_folder_contents, params) req.send_request() end |
#delete_labels(params = {}) ⇒ Struct
Deletes the specified list of labels from a resource.
1209 1210 1211 1212 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1209 def delete_labels(params = {}, = {}) req = build_request(:delete_labels, params) req.send_request() end |
#delete_notification_subscription(params = {}) ⇒ Struct
Deletes the specified subscription from the specified organization.
1235 1236 1237 1238 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1235 def delete_notification_subscription(params = {}, = {}) req = build_request(:delete_notification_subscription, params) req.send_request() end |
#delete_user(params = {}) ⇒ Struct
Deletes the specified user from a Simple AD or Microsoft AD directory.
Deleting a user immediately and permanently deletes all content in that user’s folder structure. Site retention policies do NOT apply to this type of deletion.
1267 1268 1269 1270 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1267 def delete_user(params = {}, = {}) req = build_request(:delete_user, params) req.send_request() end |
#describe_activities(params = {}) ⇒ Types::DescribeActivitiesResponse
Describes the user activities in a specified time period.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1409 1410 1411 1412 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1409 def describe_activities(params = {}, = {}) req = build_request(:describe_activities, params) req.send_request() end |
#describe_comments(params = {}) ⇒ Types::DescribeCommentsResponse
List all the comments for the specified document version.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1484 1485 1486 1487 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1484 def describe_comments(params = {}, = {}) req = build_request(:describe_comments, params) req.send_request() end |
#describe_document_versions(params = {}) ⇒ Types::DescribeDocumentVersionsResponse
Retrieves the document versions for the specified document.
By default, only active versions are returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1557 1558 1559 1560 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1557 def describe_document_versions(params = {}, = {}) req = build_request(:describe_document_versions, params) req.send_request() end |
#describe_folder_contents(params = {}) ⇒ Types::DescribeFolderContentsResponse
Describes the contents of the specified folder, including its documents and subfolders.
By default, Amazon WorkDocs returns the first 100 active document and folder metadata items. If there are more results, the response includes a marker that you can use to request the next set of results. You can also request initialized documents.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1663 1664 1665 1666 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1663 def describe_folder_contents(params = {}, = {}) req = build_request(:describe_folder_contents, params) req.send_request() end |
#describe_groups(params = {}) ⇒ Types::DescribeGroupsResponse
Describes the groups specified by the query. Groups are defined by the underlying Active Directory.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1716 1717 1718 1719 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1716 def describe_groups(params = {}, = {}) req = build_request(:describe_groups, params) req.send_request() end |
#describe_notification_subscriptions(params = {}) ⇒ Types::DescribeNotificationSubscriptionsResponse
Lists the specified notification subscriptions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1760 1761 1762 1763 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1760 def describe_notification_subscriptions(params = {}, = {}) req = build_request(:describe_notification_subscriptions, params) req.send_request() end |
#describe_resource_permissions(params = {}) ⇒ Types::DescribeResourcePermissionsResponse
Describes the permissions of a specified resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1815 1816 1817 1818 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1815 def (params = {}, = {}) req = build_request(:describe_resource_permissions, params) req.send_request() end |
#describe_root_folders(params = {}) ⇒ Types::DescribeRootFoldersResponse
Describes the current user’s special folders; the ‘RootFolder` and the `RecycleBin`. `RootFolder` is the root of user’s files and folders and ‘RecycleBin` is the root of recycled items. This is not a valid action for SigV4 (administrative API) clients.
This action requires an authentication token. To get an authentication token, register an application with Amazon WorkDocs. For more information, see [Authentication and Access Control for User Applications] in the *Amazon WorkDocs Developer Guide*.
[1]: docs.aws.amazon.com/workdocs/latest/developerguide/wd-auth-user.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1880 1881 1882 1883 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1880 def describe_root_folders(params = {}, = {}) req = build_request(:describe_root_folders, params) req.send_request() end |
#describe_users(params = {}) ⇒ Types::DescribeUsersResponse
Describes the specified users. You can describe all users or filter the results (for example, by status or organization).
By default, Amazon WorkDocs returns the first 24 active or pending users. If there are more results, the response includes a marker that you can use to request the next set of results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1996 1997 1998 1999 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1996 def describe_users(params = {}, = {}) req = build_request(:describe_users, params) req.send_request() end |
#get_current_user(params = {}) ⇒ Types::GetCurrentUserResponse
Retrieves details of the current user for whom the authentication token was generated. This is not a valid action for SigV4 (administrative API) clients.
This action requires an authentication token. To get an authentication token, register an application with Amazon WorkDocs. For more information, see [Authentication and Access Control for User Applications] in the *Amazon WorkDocs Developer Guide*.
[1]: docs.aws.amazon.com/workdocs/latest/developerguide/wd-auth-user.html
2051 2052 2053 2054 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2051 def get_current_user(params = {}, = {}) req = build_request(:get_current_user, params) req.send_request() end |
#get_document(params = {}) ⇒ Types::GetDocumentResponse
Retrieves details of a document.
2113 2114 2115 2116 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2113 def get_document(params = {}, = {}) req = build_request(:get_document, params) req.send_request() end |
#get_document_path(params = {}) ⇒ Types::GetDocumentPathResponse
Retrieves the path information (the hierarchy from the root folder) for the requested document.
By default, Amazon WorkDocs returns a maximum of 100 levels upwards from the requested document and only includes the IDs of the parent folders in the path. You can limit the maximum number of levels. You can also request the names of the parent folders.
2167 2168 2169 2170 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2167 def get_document_path(params = {}, = {}) req = build_request(:get_document_path, params) req.send_request() end |
#get_document_version(params = {}) ⇒ Types::GetDocumentVersionResponse
Retrieves version metadata for the specified document.
2230 2231 2232 2233 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2230 def get_document_version(params = {}, = {}) req = build_request(:get_document_version, params) req.send_request() end |
#get_folder(params = {}) ⇒ Types::GetFolderResponse
Retrieves the metadata of the specified folder.
2281 2282 2283 2284 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2281 def get_folder(params = {}, = {}) req = build_request(:get_folder, params) req.send_request() end |
#get_folder_path(params = {}) ⇒ Types::GetFolderPathResponse
Retrieves the path information (the hierarchy from the root folder) for the specified folder.
By default, Amazon WorkDocs returns a maximum of 100 levels upwards from the requested folder and only includes the IDs of the parent folders in the path. You can limit the maximum number of levels. You can also request the parent folder names.
2335 2336 2337 2338 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2335 def get_folder_path(params = {}, = {}) req = build_request(:get_folder_path, params) req.send_request() end |
#get_resources(params = {}) ⇒ Types::GetResourcesResponse
Retrieves a collection of resources, including folders and documents. The only ‘CollectionType` supported is `SHARED_WITH_ME`.
2422 2423 2424 2425 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2422 def get_resources(params = {}, = {}) req = build_request(:get_resources, params) req.send_request() end |
#initiate_document_version_upload(params = {}) ⇒ Types::InitiateDocumentVersionUploadResponse
Creates a new document object and version object.
The client specifies the parent folder ID and name of the document to upload. The ID is optionally specified when creating a new version of an existing document. This is the first step to upload a document. Next, upload the document to the URL returned from the call, and then call UpdateDocumentVersion.
To cancel the document upload, call AbortDocumentVersionUpload.
2513 2514 2515 2516 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2513 def initiate_document_version_upload(params = {}, = {}) req = build_request(:initiate_document_version_upload, params) req.send_request() end |
#remove_all_resource_permissions(params = {}) ⇒ Struct
Removes all the permissions from the specified resource.
2540 2541 2542 2543 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2540 def (params = {}, = {}) req = build_request(:remove_all_resource_permissions, params) req.send_request() end |
#remove_resource_permission(params = {}) ⇒ Struct
Removes the permission for the specified principal from the specified resource.
2576 2577 2578 2579 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2576 def (params = {}, = {}) req = build_request(:remove_resource_permission, params) req.send_request() end |
#restore_document_versions(params = {}) ⇒ Struct
Recovers a deleted version of an Amazon WorkDocs document.
2603 2604 2605 2606 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2603 def restore_document_versions(params = {}, = {}) req = build_request(:restore_document_versions, params) req.send_request() end |
#search_resources(params = {}) ⇒ Types::SearchResourcesResponse
Searches metadata and the content of folders, documents, document versions, and comments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2779 2780 2781 2782 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2779 def search_resources(params = {}, = {}) req = build_request(:search_resources, params) req.send_request() end |
#update_document(params = {}) ⇒ Struct
Updates the specified attributes of a document. The user must have access to both the document and its parent folder, if applicable.
2820 2821 2822 2823 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2820 def update_document(params = {}, = {}) req = build_request(:update_document, params) req.send_request() end |
#update_document_version(params = {}) ⇒ Struct
Changes the status of the document version to ACTIVE.
Amazon WorkDocs also sets its document container to ACTIVE. This is the last step in a document upload, after the client uploads the document to an S3-presigned URL returned by InitiateDocumentVersionUpload.
2860 2861 2862 2863 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2860 def update_document_version(params = {}, = {}) req = build_request(:update_document_version, params) req.send_request() end |
#update_folder(params = {}) ⇒ Struct
Updates the specified attributes of the specified folder. The user must have access to both the folder and its parent folder, if applicable.
2902 2903 2904 2905 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2902 def update_folder(params = {}, = {}) req = build_request(:update_folder, params) req.send_request() end |
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Updates the specified attributes of the specified user, and grants or revokes administrative privileges to the Amazon WorkDocs site.
2984 2985 2986 2987 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2984 def update_user(params = {}, = {}) req = build_request(:update_user, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3013 3014 3015 |
# File 'lib/aws-sdk-workdocs/client.rb', line 3013 def waiter_names [] end |