Class: Aws::WorkDocs::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::WorkDocs::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-workdocs/client.rb
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#abort_document_version_upload(params = {}) ⇒ Struct
Aborts the upload of the specified document version that was previously initiated by InitiateDocumentVersionUpload.
-
#activate_user(params = {}) ⇒ Types::ActivateUserResponse
Activates the specified user.
-
#add_resource_permissions(params = {}) ⇒ Types::AddResourcePermissionsResponse
Creates a set of permissions for the specified folder or document.
-
#create_comment(params = {}) ⇒ Types::CreateCommentResponse
Adds a new comment to the specified document version.
-
#create_custom_metadata(params = {}) ⇒ Struct
Adds one or more custom properties to the specified resource (a folder, document, or version).
-
#create_folder(params = {}) ⇒ Types::CreateFolderResponse
Creates a folder with the specified name and parent folder.
-
#create_labels(params = {}) ⇒ Struct
Adds the specified list of labels to the given resource (a document or folder).
-
#create_notification_subscription(params = {}) ⇒ Types::CreateNotificationSubscriptionResponse
Configure Amazon WorkDocs to use Amazon SNS notifications.
-
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user in a Simple AD or Microsoft AD directory.
-
#deactivate_user(params = {}) ⇒ Struct
Deactivates the specified user, which revokes the user’s access to Amazon WorkDocs.
-
#delete_comment(params = {}) ⇒ Struct
Deletes the specified comment from the document version.
-
#delete_custom_metadata(params = {}) ⇒ Struct
Deletes custom metadata from the specified resource.
-
#delete_document(params = {}) ⇒ Struct
Permanently deletes the specified document and its associated metadata.
-
#delete_folder(params = {}) ⇒ Struct
Permanently deletes the specified folder and its contents.
-
#delete_folder_contents(params = {}) ⇒ Struct
Deletes the contents of the specified folder.
-
#delete_labels(params = {}) ⇒ Struct
Deletes the specified list of labels from a resource.
-
#delete_notification_subscription(params = {}) ⇒ Struct
Deletes the specified subscription from the specified organization.
-
#delete_user(params = {}) ⇒ Struct
Deletes the specified user from a Simple AD or Microsoft AD directory.
-
#describe_activities(params = {}) ⇒ Types::DescribeActivitiesResponse
Describes the user activities in a specified time period.
-
#describe_comments(params = {}) ⇒ Types::DescribeCommentsResponse
List all the comments for the specified document version.
-
#describe_document_versions(params = {}) ⇒ Types::DescribeDocumentVersionsResponse
Retrieves the document versions for the specified document.
-
#describe_folder_contents(params = {}) ⇒ Types::DescribeFolderContentsResponse
Describes the contents of the specified folder, including its documents and subfolders.
-
#describe_groups(params = {}) ⇒ Types::DescribeGroupsResponse
Describes the groups specified by the query.
-
#describe_notification_subscriptions(params = {}) ⇒ Types::DescribeNotificationSubscriptionsResponse
Lists the specified notification subscriptions.
-
#describe_resource_permissions(params = {}) ⇒ Types::DescribeResourcePermissionsResponse
Describes the permissions of a specified resource.
-
#describe_root_folders(params = {}) ⇒ Types::DescribeRootFoldersResponse
Describes the current user’s special folders; the
RootFolderand theRecycleBin. -
#describe_users(params = {}) ⇒ Types::DescribeUsersResponse
Describes the specified users.
-
#get_current_user(params = {}) ⇒ Types::GetCurrentUserResponse
Retrieves details of the current user for whom the authentication token was generated.
-
#get_document(params = {}) ⇒ Types::GetDocumentResponse
Retrieves details of a document.
-
#get_document_path(params = {}) ⇒ Types::GetDocumentPathResponse
Retrieves the path information (the hierarchy from the root folder) for the requested document.
-
#get_document_version(params = {}) ⇒ Types::GetDocumentVersionResponse
Retrieves version metadata for the specified document.
-
#get_folder(params = {}) ⇒ Types::GetFolderResponse
Retrieves the metadata of the specified folder.
-
#get_folder_path(params = {}) ⇒ Types::GetFolderPathResponse
Retrieves the path information (the hierarchy from the root folder) for the specified folder.
-
#get_resources(params = {}) ⇒ Types::GetResourcesResponse
Retrieves a collection of resources, including folders and documents.
-
#initiate_document_version_upload(params = {}) ⇒ Types::InitiateDocumentVersionUploadResponse
Creates a new document object and version object.
-
#remove_all_resource_permissions(params = {}) ⇒ Struct
Removes all the permissions from the specified resource.
-
#remove_resource_permission(params = {}) ⇒ Struct
Removes the permission for the specified principal from the specified resource.
-
#update_document(params = {}) ⇒ Struct
Updates the specified attributes of a document.
-
#update_document_version(params = {}) ⇒ Struct
Changes the status of the document version to ACTIVE.
-
#update_folder(params = {}) ⇒ Struct
Updates the specified attributes of the specified folder.
-
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Updates the specified attributes of the specified user, and grants or revokes administrative privileges to the Amazon WorkDocs site.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
251 252 253 |
# File 'lib/aws-sdk-workdocs/client.rb', line 251 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2543 2544 2545 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2543 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2546 2547 2548 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2546 def errors_module Errors end |
Instance Method Details
#abort_document_version_upload(params = {}) ⇒ Struct
Aborts the upload of the specified document version that was previously initiated by InitiateDocumentVersionUpload. The client should make this call only when it no longer intends to upload the document version, or fails to do so.
287 288 289 290 |
# File 'lib/aws-sdk-workdocs/client.rb', line 287 def abort_document_version_upload(params = {}, = {}) req = build_request(:abort_document_version_upload, params) req.send_request() end |
#activate_user(params = {}) ⇒ Types::ActivateUserResponse
Activates the specified user. Only active users can access Amazon WorkDocs.
338 339 340 341 |
# File 'lib/aws-sdk-workdocs/client.rb', line 338 def activate_user(params = {}, = {}) req = build_request(:activate_user, params) req.send_request() end |
#add_resource_permissions(params = {}) ⇒ Types::AddResourcePermissionsResponse
Creates a set of permissions for the specified folder or document. The resource permissions are overwritten if the principals already have different permissions.
397 398 399 400 |
# File 'lib/aws-sdk-workdocs/client.rb', line 397 def (params = {}, = {}) req = build_request(:add_resource_permissions, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2521 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-workdocs' context[:gem_version] = '1.19.0' Seahorse::Client::Request.new(handlers, context) end |
#create_comment(params = {}) ⇒ Types::CreateCommentResponse
Adds a new comment to the specified document version.
483 484 485 486 |
# File 'lib/aws-sdk-workdocs/client.rb', line 483 def create_comment(params = {}, = {}) req = build_request(:create_comment, params) req.send_request() end |
#create_custom_metadata(params = {}) ⇒ Struct
Adds one or more custom properties to the specified resource (a folder, document, or version).
523 524 525 526 |
# File 'lib/aws-sdk-workdocs/client.rb', line 523 def (params = {}, = {}) req = build_request(:create_custom_metadata, params) req.send_request() end |
#create_folder(params = {}) ⇒ Types::CreateFolderResponse
Creates a folder with the specified name and parent folder.
572 573 574 575 |
# File 'lib/aws-sdk-workdocs/client.rb', line 572 def create_folder(params = {}, = {}) req = build_request(:create_folder, params) req.send_request() end |
#create_labels(params = {}) ⇒ Struct
Adds the specified list of labels to the given resource (a document or folder)
605 606 607 608 |
# File 'lib/aws-sdk-workdocs/client.rb', line 605 def create_labels(params = {}, = {}) req = build_request(:create_labels, params) req.send_request() end |
#create_notification_subscription(params = {}) ⇒ Types::CreateNotificationSubscriptionResponse
Configure Amazon WorkDocs to use Amazon SNS notifications. The endpoint receives a confirmation message, and must confirm the subscription.
For more information, see [Subscribe to Notifications] in the *Amazon WorkDocs Developer Guide*.
[1]: docs.aws.amazon.com/workdocs/latest/developerguide/subscribe-notifications.html
658 659 660 661 |
# File 'lib/aws-sdk-workdocs/client.rb', line 658 def create_notification_subscription(params = {}, = {}) req = build_request(:create_notification_subscription, params) req.send_request() end |
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user in a Simple AD or Microsoft AD directory. The status of a newly created user is “ACTIVE”. New users can access Amazon WorkDocs.
741 742 743 744 |
# File 'lib/aws-sdk-workdocs/client.rb', line 741 def create_user(params = {}, = {}) req = build_request(:create_user, params) req.send_request() end |
#deactivate_user(params = {}) ⇒ Struct
Deactivates the specified user, which revokes the user’s access to Amazon WorkDocs.
770 771 772 773 |
# File 'lib/aws-sdk-workdocs/client.rb', line 770 def deactivate_user(params = {}, = {}) req = build_request(:deactivate_user, params) req.send_request() end |
#delete_comment(params = {}) ⇒ Struct
Deletes the specified comment from the document version.
806 807 808 809 |
# File 'lib/aws-sdk-workdocs/client.rb', line 806 def delete_comment(params = {}, = {}) req = build_request(:delete_comment, params) req.send_request() end |
#delete_custom_metadata(params = {}) ⇒ Struct
Deletes custom metadata from the specified resource.
848 849 850 851 |
# File 'lib/aws-sdk-workdocs/client.rb', line 848 def (params = {}, = {}) req = build_request(:delete_custom_metadata, params) req.send_request() end |
#delete_document(params = {}) ⇒ Struct
Permanently deletes the specified document and its associated metadata.
877 878 879 880 |
# File 'lib/aws-sdk-workdocs/client.rb', line 877 def delete_document(params = {}, = {}) req = build_request(:delete_document, params) req.send_request() end |
#delete_folder(params = {}) ⇒ Struct
Permanently deletes the specified folder and its contents.
905 906 907 908 |
# File 'lib/aws-sdk-workdocs/client.rb', line 905 def delete_folder(params = {}, = {}) req = build_request(:delete_folder, params) req.send_request() end |
#delete_folder_contents(params = {}) ⇒ Struct
Deletes the contents of the specified folder.
933 934 935 936 |
# File 'lib/aws-sdk-workdocs/client.rb', line 933 def delete_folder_contents(params = {}, = {}) req = build_request(:delete_folder_contents, params) req.send_request() end |
#delete_labels(params = {}) ⇒ Struct
Deletes the specified list of labels from a resource.
969 970 971 972 |
# File 'lib/aws-sdk-workdocs/client.rb', line 969 def delete_labels(params = {}, = {}) req = build_request(:delete_labels, params) req.send_request() end |
#delete_notification_subscription(params = {}) ⇒ Struct
Deletes the specified subscription from the specified organization.
995 996 997 998 |
# File 'lib/aws-sdk-workdocs/client.rb', line 995 def delete_notification_subscription(params = {}, = {}) req = build_request(:delete_notification_subscription, params) req.send_request() end |
#delete_user(params = {}) ⇒ Struct
Deletes the specified user from a Simple AD or Microsoft AD directory.
1023 1024 1025 1026 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1023 def delete_user(params = {}, = {}) req = build_request(:delete_user, params) req.send_request() end |
#describe_activities(params = {}) ⇒ Types::DescribeActivitiesResponse
Describes the user activities in a specified time period.
1163 1164 1165 1166 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1163 def describe_activities(params = {}, = {}) req = build_request(:describe_activities, params) req.send_request() end |
#describe_comments(params = {}) ⇒ Types::DescribeCommentsResponse
List all the comments for the specified document version.
1237 1238 1239 1240 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1237 def describe_comments(params = {}, = {}) req = build_request(:describe_comments, params) req.send_request() end |
#describe_document_versions(params = {}) ⇒ Types::DescribeDocumentVersionsResponse
Retrieves the document versions for the specified document.
By default, only active versions are returned.
1309 1310 1311 1312 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1309 def describe_document_versions(params = {}, = {}) req = build_request(:describe_document_versions, params) req.send_request() end |
#describe_folder_contents(params = {}) ⇒ Types::DescribeFolderContentsResponse
Describes the contents of the specified folder, including its documents and subfolders.
By default, Amazon WorkDocs returns the first 100 active document and folder metadata items. If there are more results, the response includes a marker that you can use to request the next set of results. You can also request initialized documents.
1414 1415 1416 1417 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1414 def describe_folder_contents(params = {}, = {}) req = build_request(:describe_folder_contents, params) req.send_request() end |
#describe_groups(params = {}) ⇒ Types::DescribeGroupsResponse
Describes the groups specified by the query. Groups are defined by the underlying Active Directory.
1466 1467 1468 1469 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1466 def describe_groups(params = {}, = {}) req = build_request(:describe_groups, params) req.send_request() end |
#describe_notification_subscriptions(params = {}) ⇒ Types::DescribeNotificationSubscriptionsResponse
Lists the specified notification subscriptions.
1508 1509 1510 1511 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1508 def describe_notification_subscriptions(params = {}, = {}) req = build_request(:describe_notification_subscriptions, params) req.send_request() end |
#describe_resource_permissions(params = {}) ⇒ Types::DescribeResourcePermissionsResponse
Describes the permissions of a specified resource.
1562 1563 1564 1565 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1562 def (params = {}, = {}) req = build_request(:describe_resource_permissions, params) req.send_request() end |
#describe_root_folders(params = {}) ⇒ Types::DescribeRootFoldersResponse
Describes the current user’s special folders; the RootFolder and the RecycleBin. RootFolder is the root of user’s files and folders and RecycleBin is the root of recycled items. This is not a valid action for SigV4 (administrative API) clients.
This action requires an authentication token. To get an authentication token, register an application with Amazon WorkDocs. For more information, see [Authentication and Access Control for User Applications] in the *Amazon WorkDocs Developer Guide*.
[1]: docs.aws.amazon.com/workdocs/latest/developerguide/wd-auth-user.html
1627 1628 1629 1630 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1627 def describe_root_folders(params = {}, = {}) req = build_request(:describe_root_folders, params) req.send_request() end |
#describe_users(params = {}) ⇒ Types::DescribeUsersResponse
Describes the specified users. You can describe all users or filter the results (for example, by status or organization).
By default, Amazon WorkDocs returns the first 24 active or pending users. If there are more results, the response includes a marker that you can use to request the next set of results.
1721 1722 1723 1724 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1721 def describe_users(params = {}, = {}) req = build_request(:describe_users, params) req.send_request() end |
#get_current_user(params = {}) ⇒ Types::GetCurrentUserResponse
Retrieves details of the current user for whom the authentication token was generated. This is not a valid action for SigV4 (administrative API) clients.
1769 1770 1771 1772 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1769 def get_current_user(params = {}, = {}) req = build_request(:get_current_user, params) req.send_request() end |
#get_document(params = {}) ⇒ Types::GetDocumentResponse
Retrieves details of a document.
1832 1833 1834 1835 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1832 def get_document(params = {}, = {}) req = build_request(:get_document, params) req.send_request() end |
#get_document_path(params = {}) ⇒ Types::GetDocumentPathResponse
Retrieves the path information (the hierarchy from the root folder) for the requested document.
By default, Amazon WorkDocs returns a maximum of 100 levels upwards from the requested document and only includes the IDs of the parent folders in the path. You can limit the maximum number of levels. You can also request the names of the parent folders.
1887 1888 1889 1890 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1887 def get_document_path(params = {}, = {}) req = build_request(:get_document_path, params) req.send_request() end |
#get_document_version(params = {}) ⇒ Types::GetDocumentVersionResponse
Retrieves version metadata for the specified document.
1951 1952 1953 1954 |
# File 'lib/aws-sdk-workdocs/client.rb', line 1951 def get_document_version(params = {}, = {}) req = build_request(:get_document_version, params) req.send_request() end |
#get_folder(params = {}) ⇒ Types::GetFolderResponse
Retrieves the metadata of the specified folder.
2003 2004 2005 2006 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2003 def get_folder(params = {}, = {}) req = build_request(:get_folder, params) req.send_request() end |
#get_folder_path(params = {}) ⇒ Types::GetFolderPathResponse
Retrieves the path information (the hierarchy from the root folder) for the specified folder.
By default, Amazon WorkDocs returns a maximum of 100 levels upwards from the requested folder and only includes the IDs of the parent folders in the path. You can limit the maximum number of levels. You can also request the parent folder names.
2058 2059 2060 2061 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2058 def get_folder_path(params = {}, = {}) req = build_request(:get_folder_path, params) req.send_request() end |
#get_resources(params = {}) ⇒ Types::GetResourcesResponse
Retrieves a collection of resources, including folders and documents. The only CollectionType supported is SHARED_WITH_ME.
2146 2147 2148 2149 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2146 def get_resources(params = {}, = {}) req = build_request(:get_resources, params) req.send_request() end |
#initiate_document_version_upload(params = {}) ⇒ Types::InitiateDocumentVersionUploadResponse
Creates a new document object and version object.
The client specifies the parent folder ID and name of the document to upload. The ID is optionally specified when creating a new version of an existing document. This is the first step to upload a document. Next, upload the document to the URL returned from the call, and then call UpdateDocumentVersion.
To cancel the document upload, call AbortDocumentVersionUpload.
2238 2239 2240 2241 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2238 def initiate_document_version_upload(params = {}, = {}) req = build_request(:initiate_document_version_upload, params) req.send_request() end |
#remove_all_resource_permissions(params = {}) ⇒ Struct
Removes all the permissions from the specified resource.
2266 2267 2268 2269 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2266 def (params = {}, = {}) req = build_request(:remove_all_resource_permissions, params) req.send_request() end |
#remove_resource_permission(params = {}) ⇒ Struct
Removes the permission for the specified principal from the specified resource.
2303 2304 2305 2306 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2303 def (params = {}, = {}) req = build_request(:remove_resource_permission, params) req.send_request() end |
#update_document(params = {}) ⇒ Struct
Updates the specified attributes of a document. The user must have access to both the document and its parent folder, if applicable.
2345 2346 2347 2348 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2345 def update_document(params = {}, = {}) req = build_request(:update_document, params) req.send_request() end |
#update_document_version(params = {}) ⇒ Struct
Changes the status of the document version to ACTIVE.
Amazon WorkDocs also sets its document container to ACTIVE. This is the last step in a document upload, after the client uploads the document to an S3-presigned URL returned by InitiateDocumentVersionUpload.
2386 2387 2388 2389 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2386 def update_document_version(params = {}, = {}) req = build_request(:update_document_version, params) req.send_request() end |
#update_folder(params = {}) ⇒ Struct
Updates the specified attributes of the specified folder. The user must have access to both the folder and its parent folder, if applicable.
2429 2430 2431 2432 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2429 def update_folder(params = {}, = {}) req = build_request(:update_folder, params) req.send_request() end |
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Updates the specified attributes of the specified user, and grants or revokes administrative privileges to the Amazon WorkDocs site.
2512 2513 2514 2515 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2512 def update_user(params = {}, = {}) req = build_request(:update_user, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2536 2537 2538 |
# File 'lib/aws-sdk-workdocs/client.rb', line 2536 def waiter_names [] end |